==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_disks_list/main.tf <==
/*
Пример использования
Получение информации о дисках, которые использует аккаунт
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_disks_list" "adl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 11111

  #id диска
  #опциональный параметр
  #тип - целое число
  #disk_id = 1

  #имя диска
  #опциональный параметр
  #тип - строка
  #name = "user_name"

  #размер диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 10

  #тип диска
  #опциональный параметр
  #тип - строка
  #type = "B"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.dynamix_account_disks_list.adl
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_disks_list/main.tf <==
/*
Пример использования
Получение информации о дисках, которые использует аккаунт
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "oauth2"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_disks_list" "adl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 11111

  #id диска
  #опциональный параметр
  #тип - целое число
  #disk_id = 1

  #имя диска
  #опциональный параметр
  #тип - строка
  #name = "user_name"

  #размер диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 10

  #тип диска
  #опциональный параметр
  #тип - строка
  #type = "B"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.dynamix_account_disks_list.adl
}
